@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "addfeedwizard.h"
 
@@ -24,6 +24,7 @@
 #include "settings.h"
 
 #include <QDomDocument>
+#include <qzregexp.h>
 
 extern QString kCreateNewsTableQuery;
 
@@ -31,6 +32,7 @@ AddFeedWizard::AddFeedWizard(QWidget *parent, int curFolderId)
   : QWizard(parent),
     curFolderId_(curFolderId)
 {
+  setModal(true);
   setWindowFlags (windowFlags() & ~Qt::WindowContextHelpButtonHint);
   setWindowTitle(tr("Add Feed"));
   setWizardStyle(QWizard::ModernStyle);
@@ -62,6 +64,7 @@ AddFeedWizard::~AddFeedWizard()
   Settings settings;
   settings.setValue("addFeedWizard/geometry", saveGeometry());
 
+  updateFeeds_->disconnectObjects();
   delete updateFeeds_;
 }
 
@@ -481,8 +484,7 @@ void AddFeedWizard::getUrlDone(int result, int feedId, QString feedUrlStr,
     if (!isFeed) {
       QString str = QString::fromUtf8(data);
 
-      QRegExp rx("<link[^>]+(atom|rss)\\+xml[^>]+>",
-                 Qt::CaseInsensitive, QRegExp::RegExp2);
+      QzRegExp rx("<link[^>]+(atom|rss)\\+xml[^>]+>", Qt::CaseInsensitive);
       int pos = rx.indexIn(str);
       if (pos > -1) {
         str = rx.cap(0);
@@ -594,15 +596,12 @@ void AddFeedWizard::slotUpdateFeed(int feedId, bool, int newCount, QString)
 
 void AddFeedWizard::finish()
 {
-  int parentId = 0;
-
   QSqlQuery q;
   q.exec(QString("SELECT htmlUrl FROM feeds WHERE id=='%1'").arg(feedId_));
   if (q.first())
     htmlUrlString_ = q.value(0).toString();
 
-  if (foldersTree_->currentItem()->text(1) != "0")
-    parentId = foldersTree_->currentItem()->text(1).toInt();
+  feedParentId_ = foldersTree_->currentItem()->text(1).toInt();
 
   // Correct rowToParent field
   QList<int> idList;
@@ -619,7 +618,7 @@ void AddFeedWizard::finish()
   // Calculate row number to insert feed
   int rowToParent = 0;
   q.exec(QString("SELECT count(id) FROM feeds WHERE parentId='%1' AND id!='%2'").
-         arg(parentId).arg(feedId_));
+         arg(feedParentId_).arg(feedId_));
   if (q.next()) rowToParent = q.value(0).toInt();
 
   int auth = 0;
@@ -627,7 +626,7 @@ void AddFeedWizard::finish()
 
   q.prepare("UPDATE feeds SET text = ?, parentId = ?, rowToParent = ?, authentication = ? WHERE id == ?");
   q.addBindValue(nameFeedEdit_->text());
-  q.addBindValue(parentId);
+  q.addBindValue(feedParentId_);
   q.addBindValue(rowToParent);
   q.addBindValue(auth);
   q.addBindValue(feedId_);
@@ -650,7 +649,35 @@ void AddFeedWizard::finish()
     }
   }
 
-  feedParentId_ = parentId;
+  if (feedParentId_) {
+    q.prepare("SELECT columns, sort, sortType, "
+              "updateIntervalEnable, updateInterval, updateIntervalType, "
+              "displayEmbeddedImages, displayNews, layoutDirection, "
+              "javaScriptEnable "
+              "FROM feeds WHERE id=?");
+    q.addBindValue(feedParentId_);
+    q.exec();
+    if (q.next()) {
+      QSqlQuery q1;
+      q1.prepare("UPDATE feeds SET columns = ?, sort = ?, sortType = ?, "
+                 "updateIntervalEnable = ?, updateInterval = ?, updateIntervalType = ?, "
+                 "displayEmbeddedImages = ?, displayNews = ?, layoutDirection = ?, "
+                 "javaScriptEnable = ? "
+                 "WHERE id == ?");
+      q1.addBindValue(q.value(0).toString());
+      q1.addBindValue(q.value(1).toInt());
+      q1.addBindValue(q.value(2).toInt());
+      q1.addBindValue(q.value(3).toInt());
+      q1.addBindValue(q.value(4).toInt());
+      q1.addBindValue(q.value(5).toInt());
+      q1.addBindValue(q.value(6).toInt());
+      q1.addBindValue(q.value(7).toInt());
+      q1.addBindValue(q.value(8).toInt());
+      q1.addBindValue(q.value(9).toInt());
+      q1.addBindValue(feedId_);
+      q1.exec();
+    }
+  }
 
   accept();
 }
