@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "mainapplication.h"
 
@@ -32,12 +32,15 @@ MainApplication::MainApplication(int &argc, char **argv)
   , isPortable_(false)
   , isPortableAppsCom_(false)
   , isClosing_(false)
+  , dataDirInitialized_(false)
   , dbFileExists_(false)
+  , translator_(0)
   , mainWindow_(0)
   , networkManager_(0)
   , cookieJar_(0)
   , diskCache_(0)
   , downloadManager_(0)
+  , analytics_(0)
 {
   QString message = arguments().value(1);
   if (isRunning()) {
@@ -60,9 +63,15 @@ MainApplication::MainApplication(int &argc, char **argv)
   setApplicationName("QuiteRss");
   setOrganizationName("QuiteRss");
   setApplicationVersion(STRPRODUCTVER);
-  setWindowIcon(QIcon(":/images/quiterss32"));
+  setWindowIcon(QIcon(":/images/quiterss_128"));
   setQuitOnLastWindowClosed(false);
   QSettings::setDefaultFormat(QSettings::IniFormat);
+#if QT_VERSION >= 0x050400
+  QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
+#if QT_VERSION >= 0x050600
+  QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 
   checkPortable();
 
@@ -73,23 +82,26 @@ MainApplication::MainApplication(int &argc, char **argv)
   qWarning() << "Run application!";
 
   setStyleApplication();
-
+  setTranslateApplication();
   showSplashScreen();
 
+  createGoogleAnalytics();
+
   connectDatabase();
   setProgressSplashScreen(30);
-
+  qWarning() << "Run application 2";
   mainWindow_ = new MainWindow();
+  qWarning() << "Run application 3";
   setProgressSplashScreen(60);
 
   loadSettings();
-
+  qWarning() << "Run application 4";
   updateFeeds_ = new UpdateFeeds(mainWindow_);
   setProgressSplashScreen(90);
-
+  qWarning() << "Run application 5";
   mainWindow_->restoreFeedsOnStartUp();
   setProgressSplashScreen(100);
-
+  qWarning() << "Run application 6";
   if (!mainWindow_->startingTray_ || !mainWindow_->showTrayIcon_) {
     mainWindow_->show();
   }
@@ -141,7 +153,6 @@ void MainApplication::receiveMessage(const QString &message)
           param.remove(0, 7);
           clipboard->setText("http://" + param);
         }
-        mainWindow_->showWindows();
         mainWindow_->addFeed();
       }
     }
@@ -154,9 +165,7 @@ void MainApplication::checkPortable()
   isPortable_ = true;
   QString fileName(QCoreApplication::applicationDirPath() + "/portable.dat");
   if (!QFile::exists(fileName)) {
-    fileName = QCoreApplication::applicationDirPath() + "/" + QCoreApplication::applicationName() + ".ini";
-    if (!QFile::exists(fileName))
-      isPortable_ = false;
+    isPortable_ = false;
   }
   if (isPortable_) {
     fileName = QCoreApplication::applicationDirPath() + "/../../QuiteRSSPortable.exe";
@@ -197,6 +206,7 @@ void MainApplication::checkDir()
     QDir dir(dataDir_);
     dir.mkpath(dataDir_);
   }
+  dataDirInitialized_ = true;
 }
 
 void MainApplication::createSettings()
@@ -214,9 +224,53 @@ void MainApplication::createSettings()
   showSplashScreen_ = settings.value("showSplashScreen", true).toBool();
   updateFeedsStartUp_ = settings.value("autoUpdatefeedsStartUp", false).toBool();
   noDebugOutput_ = settings.value("noDebugOutput", true).toBool();
+
+  QString strLang;
+  QString strLocalLang = QLocale::system().name();
+  bool findLang = false;
+  QDir langDir(resourcesDir_ + "/lang");
+  foreach (QString file, langDir.entryList(QStringList("*.qm"), QDir::Files)) {
+    strLang = file.section('.', 0, 0).section('_', 1);
+    if (strLocalLang == strLang) {
+      strLang = strLocalLang;
+      findLang = true;
+      break;
+    }
+  }
+  if (!findLang) {
+    strLocalLang = strLocalLang.left(2);
+    foreach (QString file, langDir.entryList(QStringList("*.qm"), QDir::Files)) {
+      strLang = file.section('.', 0, 0).section('_', 1);
+      if (strLocalLang.contains(strLang, Qt::CaseInsensitive)) {
+        strLang = strLocalLang;
+        findLang = true;
+        break;
+      }
+    }
+  }
+  if (!findLang) strLang = "en";
+
+  langFileName_ = settings.value("langFileName", strLang).toString();
+
   settings.endGroup();
 }
 
+void MainApplication::createGoogleAnalytics()
+{
+  Settings settings;
+  bool statisticsEnabled = settings.value("Settings/statisticsEnabled2", true).toBool();
+  if (statisticsEnabled) {
+    QString clientID;
+    if (!settings.contains("GAnalytics-cid")) {
+      settings.setValue("GAnalytics-cid", QUuid::createUuid().toString());
+    }
+    clientID = settings.value("GAnalytics-cid").toString();
+    analytics_ = new GAnalytics(this, TRACKING_ID, clientID);
+    analytics_->generateUserAgentEtc();
+    analytics_->startSession();
+  }
+}
+
 void MainApplication::connectDatabase()
 {
   QString fileName(dbFileName() % ".bak");
@@ -242,21 +296,44 @@ void MainApplication::connectDatabase()
 
 void MainApplication::loadSettings()
 {
-
   c2fLoadSettings();
   reloadUserStyleBrowser();
 }
 
 void MainApplication::quitApplication()
 {
+  qWarning() << "quitApplication 1";
   delete mainWindow_;
+  qWarning() << "quitApplication 2";
   delete networkManager_;
+  delete cookieJar_;
+  delete closingWidget_;
+
+  if (analytics_) {
+    analytics_->endSession();
+    analytics_->waitForIdle();
+    delete analytics_;
+  }
 
   qWarning() << "Quit application";
 
   quit();
 }
 
+void MainApplication::showClosingWidget()
+{
+  closingWidget_ = new QWidget(0, Qt::Dialog | Qt::WindowStaysOnTopHint | Qt::WindowCloseButtonHint);
+  closingWidget_->setFocusPolicy(Qt::NoFocus);
+  QVBoxLayout *layout = new QVBoxLayout(closingWidget_);
+  layout->addWidget(new QLabel(tr("Saving data...")));
+  closingWidget_->resize(150, 20);
+  closingWidget_->show();
+  closingWidget_->move(QApplication::desktop()->availableGeometry().width() - closingWidget_->frameSize().width(),
+               QApplication::desktop()->availableGeometry().height() - closingWidget_->frameSize().height());
+  closingWidget_->setFixedSize(closingWidget_->size());
+  qApp->processEvents();
+}
+
 void MainApplication::commitData(QSessionManager &manager)
 {
   manager.release();
@@ -348,6 +425,15 @@ void MainApplication::setStyleApplication()
   setStyle(new QProxyStyle);
 }
 
+void MainApplication::setTranslateApplication()
+{
+  if (!translator_)
+    translator_ = new QTranslator(this);
+  removeTranslator(translator_);
+  translator_->load(resourcesDir_ + QString("/lang/quiterss_%1").arg(langFileName_));
+  installTranslator(translator_);
+}
+
 void MainApplication::showSplashScreen()
 {
   Settings settings;
@@ -388,7 +474,7 @@ MainWindow *MainApplication::mainWindow()
 NetworkManager *MainApplication::networkManager()
 {
   if (!networkManager_) {
-    networkManager_ = new NetworkManager(this);
+    networkManager_ = new NetworkManager(false, this);
     setDiskCache();
   }
   return networkManager_;
@@ -542,7 +628,7 @@ QUrl MainApplication::userStyleSheet(const QString &filePath) const
 {
   QString userStyle;
 
-#ifndef QZ_WS_X11
+#ifndef HAVE_X11
   // Don't grey out selection on losing focus (to prevent graying out found text)
   QString highlightColor;
   QString highlightedTextColor;
