@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,10 +13,11 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "faviconobject.h"
 #include "VersionNo.h"
+#include "mainapplication.h"
 
 #include <QDebug>
 #include <QtSql>
@@ -25,6 +26,7 @@
 #else
 #include <qwebkitversion.h>
 #endif
+#include <qzregexp.h>
 
 #define REPLY_MAX_COUNT 4
 #define REQUEST_TIMEOUT 30
@@ -46,11 +48,17 @@ FaviconObject::FaviconObject(QObject *parent)
   connect(this, SIGNAL(signalGet(QUrl,QString,int)),
           SLOT(slotGet(QUrl,QString,int)));
 
-  networkManager_ = new NetworkManager(this);
+  networkManager_ = new NetworkManager(true, this);
   connect(networkManager_, SIGNAL(finished(QNetworkReply*)),
           this, SLOT(finished(QNetworkReply*)));
 }
 
+void FaviconObject::disconnectObjects()
+{
+  disconnect(this);
+  networkManager_->disconnect(networkManager_);
+}
+
 /** @brief Put requested URL in request queue
  *----------------------------------------------------------------------------*/
 void FaviconObject::requestUrl(QString urlString, QString feedUrl)
@@ -115,6 +123,7 @@ void FaviconObject::slotGet(const QUrl &getUrl, const QString &feedUrl, const in
   currentTime_.append(REQUEST_TIMEOUT);
 
   QNetworkReply *reply = networkManager_->get(request);
+  reply->setProperty("feedReply", QVariant(true));
   requestUrl_.append(reply->url());
   networkReply_.append(reply);
 }
@@ -145,12 +154,12 @@ void FaviconObject::finished(QNetworkReply *reply)
             QString linkFavicon;
             QString str = QString::fromUtf8(data);
             if (str.contains("<html", Qt::CaseInsensitive)) {
-              QRegExp rx("<link[^>]+rel=['\"]icon['\"][^>]+>",
-                         Qt::CaseInsensitive, QRegExp::RegExp2);
+              QzRegExp rx("<link[^>]+rel=['\"]icon['\"][^>]+>",
+                          Qt::CaseInsensitive);
               int pos = rx.indexIn(str);
               if (pos == -1) {
-                rx = QRegExp("<link[^>]+rel=['\"]shortcut icon['\"][^>]+>",
-                             Qt::CaseInsensitive, QRegExp::RegExp2);
+                rx = QzRegExp("<link[^>]+rel=['\"]shortcut icon['\"][^>]+>",
+                              Qt::CaseInsensitive);
                 pos = rx.indexIn(str);
               }
               if (pos > -1) {
@@ -233,12 +242,14 @@ void FaviconObject::slotRequestTimeout()
       currentTime_.removeAt(i);
 
       int replyIndex = requestUrl_.indexOf(url);
-      requestUrl_.removeAt(replyIndex);
-      QNetworkReply *reply = networkReply_.takeAt(replyIndex);
-      reply->deleteLater();
+      if (replyIndex >= 0) {
+        requestUrl_.removeAt(replyIndex);
+        QNetworkReply *reply = networkReply_.takeAt(replyIndex);
+        reply->deleteLater();
 
-      if (cntRequests == 0) {
-        emit signalGet(url, feedUrl, 2);
+        if (cntRequests == 0) {
+          emit signalGet(url, feedUrl, 2);
+        }
       }
     } else {
       currentTime_.replace(i, time);
