@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2013 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2017 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #ifndef WEB_PLUGIN_FACTORY_H
 #define WEB_PLUGIN_FACTORY_H
@@ -25,7 +25,7 @@ class WebPage;
 class WebPluginFactory : public QWebPluginFactory
 {
 public:
-  WebPluginFactory(WebPage *page, QObject *parent);
+  WebPluginFactory(WebPage *page);
 
   virtual QObject *create(const QString &mimeType, const QUrl &url,
                           const QStringList &argumentNames,
@@ -34,6 +34,6 @@ public:
 
 private:
   WebPage *page_;
-  QObject *parent_;
+
 };
 #endif // WEB_PLUGIN_FACTORY_H
